/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */

package org.apache.tuscany.sca.contribution.processor;

import java.util.HashMap;
import java.util.Map;

/**
 * Default implementation of ContributionProcessorRegistry
 * 
 * @version $Rev: 539693 $ $Date: 2007-05-19 11:54:07 +0530 (Sat, 19 May 2007) $
 */
public class DefaultPackageProcessorExtensionPoint implements PackageProcessorExtensionPoint {

    /**
     * Processor registry
     */
    private Map<String, PackageProcessor> registry = new HashMap<String, PackageProcessor>();

    public DefaultPackageProcessorExtensionPoint() {
    }

    public void addPackageProcessor(PackageProcessor processor) {
        registry.put(processor.getPackageType(), processor);
    }

    public void removePackageProcessor(PackageProcessor processor) {
        registry.remove(processor.getPackageType());
    }

    public PackageProcessor getPackageProcessor(String contentType) {
        return registry.get(contentType);
    }
}
