/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */
package org.apache.tuscany.sca.implementation.java.introspect;

import org.apache.tuscany.sca.implementation.java.JavaImplementation;

/**
 * Implementations are responsible for walking a component implementation class,
 * adding additional component type information as appropriate
 * 
 * @version $Rev: 537426 $ $Date: 2007-05-12 19:35:05 +0530 (Sat, 12 May 2007) $
 */
public interface JavaClassIntrospector {

    /**
     * Walks the given component implementation class
     * 
     * @param clazz the component implementation class
     * @param type the component type associated with the implementation class
     * @return the updated component type
     * @throws IntrospectionException if an error is encountered evaluating the
     *             implementation class
     */
    JavaImplementation introspect(Class<?> clazz, JavaImplementation type) throws IntrospectionException;

}
